about summary refs log tree commit diff
path: root/src/expr.hh
diff options
context:
space:
mode:
authorEelco Dolstra <e.dolstra@tudelft.nl>2003-10-08T15·06+0000
committerEelco Dolstra <e.dolstra@tudelft.nl>2003-10-08T15·06+0000
commit6baa2c442035fb06652a7fad9d51df1ce41c05f9 (patch)
treec77e57b30ea01fd7ae76ca04a7d8bbc13a1a3979 /src/expr.hh
parentb9f4942bd2f8aae44db6caa5a4ebe5680880fec2 (diff)
* Get rid of identifiers since they are redundant now. This greatly
  simplifies stuff.

* The format of Nix expressions and the database schema changed
  because of this, so it's best to delete old Nix installations.

Diffstat (limited to 'src/expr.hh')
-rw-r--r--src/expr.hh24
1 files changed, 10 insertions, 14 deletions
diff --git a/src/expr.hh b/src/expr.hh
index 2a6a06a0a9..b345643223 100644
--- a/src/expr.hh
+++ b/src/expr.hh
@@ -10,31 +10,27 @@ extern "C" {
 
 /* Abstract syntax of Nix expressions. */
 
-typedef list<FSId> FSIds;
-
 struct ClosureElem
 {
-    FSId id;
-    StringSet refs;
+    PathSet refs;
 };
 
-typedef map<string, ClosureElem> ClosureElems;
+typedef map<Path, ClosureElem> ClosureElems;
 
 struct Closure
 {
-    StringSet roots;
+    PathSet roots;
     ClosureElems elems;
 };
 
-typedef map<string, FSId> DerivationOutputs;
 typedef map<string, string> StringPairs;
 
 struct Derivation
 {
-    DerivationOutputs outputs;
-    FSIdSet inputs;
+    PathSet outputs;
+    PathSet inputs; /* Nix expressions, not actual inputs */
     string platform;
-    string builder;
+    Path builder;
     Strings args;
     StringPairs env;
 };
@@ -57,11 +53,11 @@ Error badTerm(const format & f, ATerm t);
 /* Hash an aterm. */
 Hash hashTerm(ATerm t);
 
-/* Read an aterm from disk, given its id. */
-ATerm termFromId(const FSId & id);
+/* Read an aterm from disk. */
+ATerm termFromPath(const Path & path);
 
-/* Write an aterm to the Nix store directory, and return its hash. */
-FSId writeTerm(ATerm t, const string & suffix, FSId id = FSId());
+/* Write an aterm to the Nix store directory, and return its path. */
+Path writeTerm(ATerm t, const string & suffix);
 
 /* Parse a Nix expression. */
 NixExpr parseNixExpr(ATerm t);